@@ -1,6 +1,7 @@
 package Net::DAAP::DMAP;
 use strict;
-our $VERSION = '1.21';
+our $NOISY = 0;
+our $VERSION = '1.22';
 
 =pod
 
@@ -269,9 +270,11 @@ sub dmap_unpack {
     while (length $buf) {
         my ($tag, $len) = unpack("a4N", $buf);
         my $data = substr($buf, 8, $len);
+        substr($buf, 0, 8+$len) = '';
         my $type = $Types->{$tag}{TYPE};
         unless ($type) {
-            warn "Don't know about the type of $tag";
+            carp "'$tag' unknown, can't unpack" if $NOISY;
+            next;
         }
 
         if ($type == 12) {
@@ -285,7 +288,6 @@ sub dmap_unpack {
             $data = unpack($Type_To_Unpack{$type}, $data);
         }
         push @tags, [ $Types->{$tag}{NAME}, $data ];
-        substr($buf, 0, 8+$len) = '';
     }
 
     return \@tags;
@@ -364,7 +366,7 @@ sub update_content_codes {
       if ($f->[0] eq 'dmap.contentcodesname') { $name = $f->[1] }
       if ($f->[0] eq 'dmap.contentcodestype') { $type = $f->[1] }
     }
-    if ($name eq 'mcnm') { $type = 9 } # string names please
+    if ($id eq 'mcnm') { $type = 9 } # string names please
     my $record = { NAME => $name, ID => $id, TYPE => $type };
     $short->{$id} = $record;
   }
@@ -383,12 +385,12 @@ sub dmap_pack {
         # something it doesn't know the content-code of, like aeSV
         # which is new to 4.5
         unless ($name) {
-            carp "element without a name - skipping";
+            carp "element without a name - skipping" if $NOISY;
             next;
         }
         # or, it may be we don't know what kind of thing this is
         unless ($by_name{ $name }) {
-            carp "we don't know the type for '$name' elements - skipping";
+            carp "$name has unknown type - skipping" if $NOISY;
             next;
         }
 
@@ -414,265 +416,38 @@ sub dmap_pack {
     return $out;
 }
 
-
-
 1;
 
 __DATA__
-{
-          'mper' => {
-                      'ID' => 'mper',
-                      'NAME' => 'dmap.persistentid',
-                      'TYPE' => 7
-                    },
-          'arif' => {
-                      'ID' => 'arif',
-                      'NAME' => 'daap.resolveinfo',
+        {
+          'abal' => {
+                      'ID' => 'abal',
+                      'NAME' => 'daap.browsealbumlisting',
                       'TYPE' => 12
                     },
-          'mcon' => {
-                      'ID' => 'mcon',
-                      'NAME' => 'dmap.container',
-                      'TYPE' => 12
-                    },
-          'mbcl' => {
-                      'ID' => 'mbcl',
-                      'NAME' => 'dmap.bag',
-                      'TYPE' => 12
-                    },
-          'mcnm' => {
-                      'ID' => 'mcnm',
-                      'NAME' => 'dmap.contentcodesnumber',
-                      'TYPE' => 9
-                    },
-          'mudl' => {
-                      'ID' => 'mudl',
-                      'NAME' => 'dmap.deletedidlisting',
-                      'TYPE' => 12
-                    },
-          'asda' => {
-                      'ID' => 'asda',
-                      'NAME' => 'daap.songdateadded',
-                      'TYPE' => 10
-                    },
-          'asyr' => {
-                      'ID' => 'asyr',
-                      'NAME' => 'daap.songyear',
-                      'TYPE' => 3
-                    },
-          'mlid' => {
-                      'ID' => 'mlid',
-                      'NAME' => 'dmap.sessionid',
-                      'TYPE' => 5
-                    },
-          'msex' => {
-                      'ID' => 'msex',
-                      'NAME' => 'dmap.supportsextensions',
-                      'TYPE' => 1
-                    },
-          'assr' => {
-                      'ID' => 'assr',
-                      'NAME' => 'daap.songsamplerate',
-                      'TYPE' => 5
-                    },
-          'asdb' => {
-                      'ID' => 'asdb',
-                      'NAME' => 'daap.songdisabled',
-                      'TYPE' => 1
-                    },
-          'mlit' => {
-                      'ID' => 'mlit',
-                      'NAME' => 'dmap.listingitem',
-                      'TYPE' => 12
-                    },
-          'asco' => {
-                      'ID' => 'asco',
-                      'NAME' => 'daap.songcompilation',
-                      'TYPE' => 1
-                    },
-          'asdm' => {
-                      'ID' => 'asdm',
-                      'NAME' => 'daap.songdatemodified',
-                      'TYPE' => 10
-                    },
-          'aeNV' => {
-                      'ID' => 'aeNV',
-                      'NAME' => 'com.apple.itunes.norm-volume',
-                      'TYPE' => 5
-                    },
-          'mccr' => {
-                      'ID' => 'mccr',
-                      'NAME' => 'dmap.contentcodesresponse',
-                      'TYPE' => 12
-                    },
-          'msts' => {
-                      'ID' => 'msts',
-                      'NAME' => 'dmap.statusstring',
-                      'TYPE' => 9
-                    },
-          'ascp' => {
-                      'ID' => 'ascp',
-                      'NAME' => 'daap.songcomposer',
-                      'TYPE' => 9
-                    },
-          'aseq' => {
-                      'ID' => 'aseq',
-                      'NAME' => 'daap.songeqpreset',
-                      'TYPE' => 9
-                    },
-          'mstt' => {
-                      'ID' => 'mstt',
-                      'NAME' => 'dmap.status',
-                      'TYPE' => 5
-                    },
-          'msal' => {
-                      'ID' => 'msal',
-                      'NAME' => 'dmap.supportsautologout',
-                      'TYPE' => 1
-                    },
-          'muty' => {
-                      'ID' => 'muty',
-                      'NAME' => 'dmap.updatetype',
-                      'TYPE' => 1
-                    },
-          'asfm' => {
-                      'ID' => 'asfm',
-                      'NAME' => 'daap.songformat',
-                      'TYPE' => 9
-                    },
-          'abgn' => {
-                      'ID' => 'abgn',
-                      'NAME' => 'daap.browsegenrelisting',
-                      'TYPE' => 12
-                    },
-          'mupd' => {
-                      'ID' => 'mupd',
-                      'NAME' => 'dmap.updateresponse',
-                      'TYPE' => 12
-                    },
-          'asal' => {
-                      'ID' => 'asal',
-                      'NAME' => 'daap.songalbum',
-                      'TYPE' => 9
-                    },
-          'abro' => {
-                      'ID' => 'abro',
-                      'NAME' => 'daap.databasebrowse',
-                      'TYPE' => 12
-                    },
-          'miid' => {
-                      'ID' => 'miid',
-                      'NAME' => 'dmap.itemid',
-                      'TYPE' => 5
-                    },
-          'ascm' => {
-                      'ID' => 'ascm',
-                      'NAME' => 'daap.songcomment',
-                      'TYPE' => 9
-                    },
-          'mspi' => {
-                      'ID' => 'mspi',
-                      'NAME' => 'dmap.supportspersistentids',
-                      'TYPE' => 1
-                    },
-          'musr' => {
-                      'ID' => 'musr',
-                      'NAME' => 'dmap.serverrevision',
-                      'TYPE' => 5
-                    },
-          'assz' => {
-                      'ID' => 'assz',
-                      'NAME' => 'daap.songsize',
-                      'TYPE' => 5
-                    },
-          'msau' => {
-                      'ID' => 'msau',
-                      'NAME' => 'dmap.authenticationmethod',
-                      'TYPE' => 1
-                    },
-          'astm' => {
-                      'ID' => 'astm',
-                      'NAME' => 'daap.songtime',
-                      'TYPE' => 5
-                    },
-          'asdn' => {
-                      'ID' => 'asdn',
-                      'NAME' => 'daap.songdiscnumber',
-                      'TYPE' => 3
-                    },
-          'astn' => {
-                      'ID' => 'astn',
-                      'NAME' => 'daap.songtracknumber',
-                      'TYPE' => 3
-                    },
-          'assp' => {
-                      'ID' => 'assp',
-                      'NAME' => 'daap.songstoptime',
-                      'TYPE' => 5
-                    },
-          'aeSP' => {
-                      'ID' => 'aeSP',
-                      'NAME' => 'com.apple.itunes.smart-playlist',
-                      'TYPE' => 1
-                    },
-          'asgn' => {
-                      'ID' => 'asgn',
-                      'NAME' => 'daap.songgenre',
-                      'TYPE' => 9
-                    },
-          'mpco' => {
-                      'ID' => 'mpco',
-                      'NAME' => 'dmap.parentcontainerid',
-                      'TYPE' => 5
-                    },
-          'msrs' => {
-                      'ID' => 'msrs',
-                      'NAME' => 'dmap.supportsresolve',
-                      'TYPE' => 1
-                    },
-          'avdb' => {
-                      'ID' => 'avdb',
-                      'NAME' => 'daap.serverdatabases',
-                      'TYPE' => 12
-                    },
-          'msrv' => {
-                      'ID' => 'msrv',
-                      'NAME' => 'dmap.serverinforesponse',
-                      'TYPE' => 12
-                    },
-          'mslr' => {
-                      'ID' => 'mslr',
-                      'NAME' => 'dmap.loginrequired',
-                      'TYPE' => 1
-                    },
-          'msup' => {
-                      'ID' => 'msup',
-                      'NAME' => 'dmap.supportsupdate',
-                      'TYPE' => 1
-                    },
-          'mimc' => {
-                      'ID' => 'mimc',
-                      'NAME' => 'dmap.itemcount',
-                      'TYPE' => 5
-                    },
-          'mcna' => {
-                      'ID' => 'mcna',
-                      'NAME' => 'dmap.contentcodesname',
-                      'TYPE' => 9
-                    },
-          'apro' => {
-                      'ID' => 'apro',
-                      'NAME' => 'daap.protocolversion',
-                      'TYPE' => 11
-                    },
           'abar' => {
                       'ID' => 'abar',
                       'NAME' => 'daap.browseartistlisting',
                       'TYPE' => 12
                     },
-          'mdcl' => {
-                      'ID' => 'mdcl',
-                      'NAME' => 'dmap.dictionary',
+          'abcp' => {
+                      'ID' => 'abcp',
+                      'NAME' => 'daap.browsecomposerlisting',
+                      'TYPE' => 12
+                    },
+          'abgn' => {
+                      'ID' => 'abgn',
+                      'NAME' => 'daap.browsegenrelisting',
+                      'TYPE' => 12
+                    },
+          'abpl' => {
+                      'ID' => 'abpl',
+                      'NAME' => 'daap.baseplaylist',
+                      'TYPE' => 1
+                    },
+          'abro' => {
+                      'ID' => 'abro',
+                      'NAME' => 'daap.databasebrowse',
                       'TYPE' => 12
                     },
           'adbs' => {
@@ -680,189 +455,414 @@ __DATA__
                       'NAME' => 'daap.databasesongs',
                       'TYPE' => 12
                     },
+          'aeNV' => {
+                      'ID' => 'aeNV',
+                      'NAME' => 'com.apple.itunes.norm-volume',
+                      'TYPE' => 5
+                    },
+          'aeSP' => {
+                      'ID' => 'aeSP',
+                      'NAME' => 'com.apple.itunes.smart-playlist',
+                      'TYPE' => 1
+                    },
           'aply' => {
                       'ID' => 'aply',
                       'NAME' => 'daap.databaseplaylists',
                       'TYPE' => 12
                     },
+          'apro' => {
+                      'ID' => 'apro',
+                      'NAME' => 'daap.protocolversion',
+                      'TYPE' => 11
+                    },
+          'apso' => {
+                      'ID' => 'apso',
+                      'NAME' => 'daap.playlistsongs',
+                      'TYPE' => 12
+                    },
+          'arif' => {
+                      'ID' => 'arif',
+                      'NAME' => 'daap.resolveinfo',
+                      'TYPE' => 12
+                    },
+          'arsv' => {
+                      'ID' => 'arsv',
+                      'NAME' => 'daap.resolve',
+                      'TYPE' => 12
+                    },
+          'asal' => {
+                      'ID' => 'asal',
+                      'NAME' => 'daap.songalbum',
+                      'TYPE' => 9
+                    },
+          'asar' => {
+                      'ID' => 'asar',
+                      'NAME' => 'daap.songartist',
+                      'TYPE' => 9
+                    },
+          'asbr' => {
+                      'ID' => 'asbr',
+                      'NAME' => 'daap.songbitrate',
+                      'TYPE' => 3
+                    },
+          'asbt' => {
+                      'ID' => 'asbt',
+                      'NAME' => 'daap.songbeatsperminute',
+                      'TYPE' => 3
+                    },
+          'ascm' => {
+                      'ID' => 'ascm',
+                      'NAME' => 'daap.songcomment',
+                      'TYPE' => 9
+                    },
+          'asco' => {
+                      'ID' => 'asco',
+                      'NAME' => 'daap.songcompilation',
+                      'TYPE' => 1
+                    },
+          'ascp' => {
+                      'ID' => 'ascp',
+                      'NAME' => 'daap.songcomposer',
+                      'TYPE' => 9
+                    },
+          'asda' => {
+                      'ID' => 'asda',
+                      'NAME' => 'daap.songdateadded',
+                      'TYPE' => 10
+                    },
+          'asdb' => {
+                      'ID' => 'asdb',
+                      'NAME' => 'daap.songdisabled',
+                      'TYPE' => 1
+                    },
+          'asdc' => {
+                      'ID' => 'asdc',
+                      'NAME' => 'daap.songdisccount',
+                      'TYPE' => 3
+                    },
+          'asdk' => {
+                      'ID' => 'asdk',
+                      'NAME' => 'daap.songdatakind',
+                      'TYPE' => 1
+                    },
+          'asdm' => {
+                      'ID' => 'asdm',
+                      'NAME' => 'daap.songdatemodified',
+                      'TYPE' => 10
+                    },
+          'asdn' => {
+                      'ID' => 'asdn',
+                      'NAME' => 'daap.songdiscnumber',
+                      'TYPE' => 3
+                    },
+          'asdt' => {
+                      'ID' => 'asdt',
+                      'NAME' => 'daap.songdescription',
+                      'TYPE' => 9
+                    },
+          'aseq' => {
+                      'ID' => 'aseq',
+                      'NAME' => 'daap.songeqpreset',
+                      'TYPE' => 9
+                    },
+          'asfm' => {
+                      'ID' => 'asfm',
+                      'NAME' => 'daap.songformat',
+                      'TYPE' => 9
+                    },
+          'asgn' => {
+                      'ID' => 'asgn',
+                      'NAME' => 'daap.songgenre',
+                      'TYPE' => 9
+                    },
+          'asrv' => {
+                      'ID' => 'asrv',
+                      'NAME' => 'daap.songrelativevolume',
+                      'TYPE' => 1
+                    },
+          'assp' => {
+                      'ID' => 'assp',
+                      'NAME' => 'daap.songstoptime',
+                      'TYPE' => 5
+                    },
+          'assr' => {
+                      'ID' => 'assr',
+                      'NAME' => 'daap.songsamplerate',
+                      'TYPE' => 5
+                    },
+          'asst' => {
+                      'ID' => 'asst',
+                      'NAME' => 'daap.songstarttime',
+                      'TYPE' => 5
+                    },
+          'assz' => {
+                      'ID' => 'assz',
+                      'NAME' => 'daap.songsize',
+                      'TYPE' => 5
+                    },
+          'astc' => {
+                      'ID' => 'astc',
+                      'NAME' => 'daap.songtrackcount',
+                      'TYPE' => 3
+                    },
+          'astm' => {
+                      'ID' => 'astm',
+                      'NAME' => 'daap.songtime',
+                      'TYPE' => 5
+                    },
+          'astn' => {
+                      'ID' => 'astn',
+                      'NAME' => 'daap.songtracknumber',
+                      'TYPE' => 3
+                    },
+          'asul' => {
+                      'ID' => 'asul',
+                      'NAME' => 'daap.songdataurl',
+                      'TYPE' => 9
+                    },
+          'asur' => {
+                      'ID' => 'asur',
+                      'NAME' => 'daap.songuserrating',
+                      'TYPE' => 1
+                    },
+          'asyr' => {
+                      'ID' => 'asyr',
+                      'NAME' => 'daap.songyear',
+                      'TYPE' => 3
+                    },
+          'avdb' => {
+                      'ID' => 'avdb',
+                      'NAME' => 'daap.serverdatabases',
+                      'TYPE' => 12
+                    },
+          'mbcl' => {
+                      'ID' => 'mbcl',
+                      'NAME' => 'dmap.bag',
+                      'TYPE' => 12
+                    },
+          'mccr' => {
+                      'ID' => 'mccr',
+                      'NAME' => 'dmap.contentcodesresponse',
+                      'TYPE' => 12
+                    },
+          'mcna' => {
+                      'ID' => 'mcna',
+                      'NAME' => 'dmap.contentcodesname',
+                      'TYPE' => 9
+                    },
+          'mcnm' => {
+                      'ID' => 'mcnm',
+                      'NAME' => 'dmap.contentcodesnumber',
+                      'TYPE' => 9
+                    },
+          'mcon' => {
+                      'ID' => 'mcon',
+                      'NAME' => 'dmap.container',
+                      'TYPE' => 12
+                    },
+          'mctc' => {
+                      'ID' => 'mctc',
+                      'NAME' => 'dmap.containercount',
+                      'TYPE' => 5
+                    },
+          'mcti' => {
+                      'ID' => 'mcti',
+                      'NAME' => 'dmap.containeritemid',
+                      'TYPE' => 5
+                    },
+          'mcty' => {
+                      'ID' => 'mcty',
+                      'NAME' => 'dmap.contentcodestype',
+                      'TYPE' => 3
+                    },
+          'mdcl' => {
+                      'ID' => 'mdcl',
+                      'NAME' => 'dmap.dictionary',
+                      'TYPE' => 12
+                    },
+          'miid' => {
+                      'ID' => 'miid',
+                      'NAME' => 'dmap.itemid',
+                      'TYPE' => 5
+                    },
+          'mikd' => {
+                      'ID' => 'mikd',
+                      'NAME' => 'dmap.itemkind',
+                      'TYPE' => 1
+                    },
+          'mimc' => {
+                      'ID' => 'mimc',
+                      'NAME' => 'dmap.itemcount',
+                      'TYPE' => 5
+                    },
+          'minm' => {
+                      'ID' => 'minm',
+                      'NAME' => 'dmap.itemname',
+                      'TYPE' => 9
+                    },
+          'mlcl' => {
+                      'ID' => 'mlcl',
+                      'NAME' => 'dmap.listing',
+                      'TYPE' => 12
+                    },
+          'mlid' => {
+                      'ID' => 'mlid',
+                      'NAME' => 'dmap.sessionid',
+                      'TYPE' => 5
+                    },
+          'mlit' => {
+                      'ID' => 'mlit',
+                      'NAME' => 'dmap.listingitem',
+                      'TYPE' => 12
+                    },
+          'mlog' => {
+                      'ID' => 'mlog',
+                      'NAME' => 'dmap.loginresponse',
+                      'TYPE' => 12
+                    },
+          'mpco' => {
+                      'ID' => 'mpco',
+                      'NAME' => 'dmap.parentcontainerid',
+                      'TYPE' => 5
+                    },
+          'mper' => {
+                      'ID' => 'mper',
+                      'NAME' => 'dmap.persistentid',
+                      'TYPE' => 7
+                    },
+          'mpro' => {
+                      'ID' => 'mpro',
+                      'NAME' => 'dmap.protocolversion',
+                      'TYPE' => 11
+                    },
+          'mrco' => {
+                      'ID' => 'mrco',
+                      'NAME' => 'dmap.returnedcount',
+                      'TYPE' => 5
+                    },
+          'msal' => {
+                      'ID' => 'msal',
+                      'NAME' => 'dmap.supportsautologout',
+                      'TYPE' => 1
+                    },
+          'msau' => {
+                      'ID' => 'msau',
+                      'NAME' => 'dmap.authenticationmethod',
+                      'TYPE' => 1
+                    },
+          'msbr' => {
+                      'ID' => 'msbr',
+                      'NAME' => 'dmap.supportsbrowse',
+                      'TYPE' => 1
+                    },
+          'msdc' => {
+                      'ID' => 'msdc',
+                      'NAME' => 'dmap.databasescount',
+                      'TYPE' => 5
+                    },
+          'msex' => {
+                      'ID' => 'msex',
+                      'NAME' => 'dmap.supportsextensions',
+                      'TYPE' => 1
+                    },
+          'msix' => {
+                      'ID' => 'msix',
+                      'NAME' => 'dmap.supportsindex',
+                      'TYPE' => 1
+                    },
+          'mslr' => {
+                      'ID' => 'mslr',
+                      'NAME' => 'dmap.loginrequired',
+                      'TYPE' => 1
+                    },
+          'mspi' => {
+                      'ID' => 'mspi',
+                      'NAME' => 'dmap.supportspersistentids',
+                      'TYPE' => 1
+                    },
+          'msqy' => {
+                      'ID' => 'msqy',
+                      'NAME' => 'dmap.supportsquery',
+                      'TYPE' => 1
+                    },
+          'msrs' => {
+                      'ID' => 'msrs',
+                      'NAME' => 'dmap.supportsresolve',
+                      'TYPE' => 1
+                    },
+          'msrv' => {
+                      'ID' => 'msrv',
+                      'NAME' => 'dmap.serverinforesponse',
+                      'TYPE' => 12
+                    },
           'mstm' => {
                       'ID' => 'mstm',
                       'NAME' => 'dmap.timeoutinterval',
                       'TYPE' => 5
                     },
-          'asbt' => {
-                      'ID' => 'asbt',
-                      'NAME' => 'daap.songbeatsperminute',
-                      'TYPE' => 3
-                    },
-          'asrv' => {
-                      'ID' => 'asrv',
-                      'NAME' => 'daap.songrelativevolume',
-                      'TYPE' => 1
-                    },
-          'mcti' => {
-                      'ID' => 'mcti',
-                      'NAME' => 'dmap.containeritemid',
-                      'TYPE' => 5
-                    },
-          'asdk' => {
-                      'ID' => 'asdk',
-                      'NAME' => 'daap.songdatakind',
-                      'TYPE' => 1
-                    },
-          'mlog' => {
-                      'ID' => 'mlog',
-                      'NAME' => 'dmap.loginresponse',
-                      'TYPE' => 12
-                    },
-          'asbr' => {
-                      'ID' => 'asbr',
-                      'NAME' => 'daap.songbitrate',
-                      'TYPE' => 3
-                    },
-          'msix' => {
-                      'ID' => 'msix',
-                      'NAME' => 'dmap.supportsindex',
-                      'TYPE' => 1
-                    },
-          'mcty' => {
-                      'ID' => 'mcty',
-                      'NAME' => 'dmap.contentcodestype',
-                      'TYPE' => 3
-                    },
-          'arsv' => {
-                      'ID' => 'arsv',
-                      'NAME' => 'daap.resolve',
-                      'TYPE' => 12
-                    },
-          'msqy' => {
-                      'ID' => 'msqy',
-                      'NAME' => 'dmap.supportsquery',
-                      'TYPE' => 1
-                    },
-          'abal' => {
-                      'ID' => 'abal',
-                      'NAME' => 'daap.browsealbumlisting',
-                      'TYPE' => 12
-                    },
-          'mikd' => {
-                      'ID' => 'mikd',
-                      'NAME' => 'dmap.itemkind',
-                      'TYPE' => 1
-                    },
-          'astc' => {
-                      'ID' => 'astc',
-                      'NAME' => 'daap.songtrackcount',
-                      'TYPE' => 3
-                    },
-          'minm' => {
-                      'ID' => 'minm',
-                      'NAME' => 'dmap.itemname',
+          'msts' => {
+                      'ID' => 'msts',
+                      'NAME' => 'dmap.statusstring',
                       'TYPE' => 9
                     },
-          'mctc' => {
-                      'ID' => 'mctc',
-                      'NAME' => 'dmap.containercount',
+          'mstt' => {
+                      'ID' => 'mstt',
+                      'NAME' => 'dmap.status',
                       'TYPE' => 5
                     },
-          'mrco' => {
-                      'ID' => 'mrco',
-                      'NAME' => 'dmap.returnedcount',
-                      'TYPE' => 5
+          'msup' => {
+                      'ID' => 'msup',
+                      'NAME' => 'dmap.supportsupdate',
+                      'TYPE' => 1
                     },
           'mtco' => {
                       'ID' => 'mtco',
                       'NAME' => 'dmap.specifiedtotalcount',
                       'TYPE' => 5
                     },
-          'abpl' => {
-                      'ID' => 'abpl',
-                      'NAME' => 'daap.baseplaylist',
-                      'TYPE' => 1
+          'mudl' => {
+                      'ID' => 'mudl',
+                      'NAME' => 'dmap.deletedidlisting',
+                      'TYPE' => 12
                     },
-          'asur' => {
-                      'ID' => 'asur',
-                      'NAME' => 'daap.songuserrating',
-                      'TYPE' => 1
+          'mupd' => {
+                      'ID' => 'mupd',
+                      'NAME' => 'dmap.updateresponse',
+                      'TYPE' => 12
                     },
-          'asst' => {
-                      'ID' => 'asst',
-                      'NAME' => 'daap.songstarttime',
+          'musr' => {
+                      'ID' => 'musr',
+                      'NAME' => 'dmap.serverrevision',
                       'TYPE' => 5
                     },
-          'abcp' => {
-                      'ID' => 'abcp',
-                      'NAME' => 'daap.browsecomposerlisting',
-                      'TYPE' => 12
-                    },
-          'apso' => {
-                      'ID' => 'apso',
-                      'NAME' => 'daap.playlistsongs',
-                      'TYPE' => 12
-                    },
-          'asdt' => {
-                      'ID' => 'asdt',
-                      'NAME' => 'daap.songdescription',
-                      'TYPE' => 9
-                    },
-          'mpro' => {
-                      'ID' => 'mpro',
-                      'NAME' => 'dmap.protocolversion',
-                      'TYPE' => 11
-                    },
-          'msbr' => {
-                      'ID' => 'msbr',
-                      'NAME' => 'dmap.supportsbrowse',
+          'muty' => {
+                      'ID' => 'muty',
+                      'NAME' => 'dmap.updatetype',
                       'TYPE' => 1
                     },
-          'mlcl' => {
-                      'ID' => 'mlcl',
-                      'NAME' => 'dmap.listing',
-                      'TYPE' => 12
-                    },
-          'asdc' => {
-                      'ID' => 'asdc',
-                      'NAME' => 'daap.songdisccount',
-                      'TYPE' => 3
-                    },
-          'asar' => {
-                      'ID' => 'asar',
-                      'NAME' => 'daap.songartist',
-                      'TYPE' => 9
-                    },
-          'asul' => {
-                      'ID' => 'asul',
-                      'NAME' => 'daap.songdataurl',
-                      'TYPE' => 9
-                    },
-          'msdc' => {
-                      'ID' => 'msdc',
-                      'NAME' => 'dmap.databasescount',
-                      'TYPE' => 5
-                    },
-          'ppro' => {
-                      'ID' => 'ppro',
-                      'NAME' => 'dpap.protocolversion',
-                      'TYPE' => 11
-                    },
-          'pimf' => {
-                      'ID' => 'pimf',
-                      'NAME' => 'dpap.imagefilename',
-                      'TYPE' => 9
-                    },
           'pasp' => {
                       'ID' => 'pasp',
                       'NAME' => 'dpap.aspectratio',
                       'TYPE' => 9
                     },
+          'pfdt' => {
+                      'ID' => 'pfdt',
+                      'NAME' => 'dpap.picturedata',
+                      'TYPE' => 9
+                    },
           'picd' => {
                       'ID' => 'picd',
                       'NAME' => 'dpap.creationdate',
                       'TYPE' => 5
                     },
-          'pfdt' => {
-                      'ID' => 'pfdt',
-                      'NAME' => 'dpap.picturedata',
+          'pimf' => {
+                      'ID' => 'pimf',
+                      'NAME' => 'dpap.imagefilename',
                       'TYPE' => 9
                     },
-        };
+          'ppro' => {
+                      'ID' => 'ppro',
+                      'NAME' => 'dpap.protocolversion',
+                      'TYPE' => 11
+                    }
+        }
